@@ -37,6 +37,10 @@
 //! let token = sm.lookup_token(0, 0).unwrap(); // line-number and column
 //! println!("token: {}", token);
 //! ```
+#![cfg_attr(feature="serde_macros", feature(custom_derive, plugin))]
+#![cfg_attr(feature="serde_macros", plugin(serde_macros))]
+
+extern crate base64;
 extern crate serde;
 extern crate serde_json;
 
@@ -45,12 +49,14 @@ mod macros;
 pub use types::{RawToken, Token, TokenIter, SourceMap, SourceMapIndex,
                 SourceMapSection, SourceMapSectionIter};
 pub use errors::{Result, Error};
-pub use decoder::{decode, DecodedMap};
+pub use decoder::{decode, decode_data_url, DecodedMap};
+pub use detector::{SourceMapRef, locate_sourcemap_reference};
 
 mod errors;
 mod types;
 mod jsontypes;
 mod decoder;
+mod detector;
 
 #[doc(hidden)]
 pub mod internals {
